<?php 

/* Shortcode handler */

add_action( 'wpcf7_init', 'wpcf7_add_shortcode_file_drop_uploader', 15 );

function wpcf7_add_shortcode_file_drop_uploader() {
    if(version_compare(WPCF7_VERSION, "4.7" ) >= 0) {
        wpcf7_add_form_tag( array( 'dropuploader', 'dropuploader*' ),
        'wpcf7_file_shortcode_handler_drop_uploader', true );
    } else {
        wpcf7_add_shortcode( array( 'dropuploader', 'dropuploader*' ),
        'wpcf7_file_shortcode_handler_drop_uploader', true );
    }
}

function wpcf7_file_shortcode_handler_drop_uploader( $tag ) {
    do_action('cf7du_res');

    if(version_compare(WPCF7_VERSION, "4.7" ) >= 0) {
        $tag = new WPCF7_FormTag( $tag );
    } else {
        $tag = new WPCF7_Shortcode( $tag );
    }

    if ( empty( $tag->name ) ) {
        return '';
    }

    $validation_error = wpcf7_get_validation_error( $tag->name );

    $class = wpcf7_form_controls_class( $tag->type );

    if ( $validation_error ) {
        $class .= ' wpcf7-not-valid';
    }

    $atts = array();

    $file_ext_mime = array(
        'jpg' => 'image/jpeg',
        'jpeg' => 'image/jpeg',
        'png' => 'image/png',
        'gif' => 'image/gif',
        'pdf' => 'application/pdf,pdf',
        'zip' => 'application/zip,zip',
        'doc' => 'application/msword,doc',
        'docx' => 'application/vnd.openxmlformats-officedocument.wordprocessingml.document,docx',
        'ppt' => 'application/vnd.ms-powerpoint,ppt',
        'pptx' => 'application/vnd.openxmlformats-officedocument.presentationml.presentation,pptx',
        'xlsx' => 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet,xlsx',
        'xls' => 'application/vnd.ms-excel,xls',
        'odt' => 'application/vnd.oasis.opendocument.text,odt',
        'avi' => 'video/x-msvideo,avi',
        'oga' => 'audio/ogg,oga',
        'ogv' => 'video/ogg,ogv',
        'aac' => 'audio/aac,aac',
        'mov' => 'video/quicktime,mov',
        'mp3' => 'audio/mpeg,mp3',
        'mp4' => 'video/mp4,mp4',
        'mpg' => 'video/mpeg,mpg',
        'wav' => 'audio/x-wav,wav',
        'wmv' => 'video/x-ms-wmv,wmv',
        // Extended
        'sldprt' => 'sldprt',
        'sldasm' => 'sldasm',
        'slddrw' => 'slddrw',
        'prt' => 'application/pro_eng,prt',
        'asm' => 'text/x-asm,asm',
        'drw' => 'application/drafting,drw',
        'psd' => 'application/octet-stream,psd',
        'ai' => 'application/postscript,ai',
        'lfp' => 'lfp',
        'sldlfp' => 'sldlfp',
        'prddot' => 'prddot',
        'asmdot' => 'asmdot',
        'drwdot' => 'drwdot',
        'dxf' => 'application/dxf,image/vnd.dwg,image/x-dwg,dxf',
        'dwg' => 'application/acad,image/vnd.dwg,image/x-dwg,dwg',
        'iges' => 'application/iges,model/iges,iges',
        'igs' => 'application/iges,model/iges,igs',
        'step' => 'application/step,step',
        'stp' => 'application/step,stp',
        'stl' => 'application/sla,application/vnd.ms-pki.stl,application/x-navistyle,stl',
        'sat' => 'sat',
        'vda' => 'application/vda,vda',
        'wrl' => 'application/x-world,model/vrml,x-world/x-vrml,wrl',
        'cgr' => 'cgr',
        'catpart' => 'catpart',
        'catproduct' => 'catproduct',
        'xpr' => 'xpr',
        'ipt' => 'ipt',
        'iam' => 'iam',
        'par' => 'par',
        'psm' => 'psm',
        '3ds' => '3ds',
        'obj' => 'obj',
        'blend' => 'blend',
        'cad' => 'cad',
        '3dm' => 'x-world/x-3dmf,3dm',
        '3dmf' => 'x-world/x-3dmf,3dmf',
        'tiff' => 'image/tiff,tiff',
        'cr2' => 'image/x-raw,image/x-canon-cr2,cr2',
        'rar' => 'application/x-rar-compressed,rar',
        'msg' => 'application/vnd.ms-outlook,msg',
        'eml' => 'message/rfc822,eml',
    );

    $allowed_file_types = array();

    $allowed_mime_type = '';

    if ( $file_types_a = $tag->get_option( 'filetypes' ) ) {
        foreach ( $file_types_a as $file_types ) {
            $file_types = explode( '|', $file_types );

            foreach ( $file_types as $file_type ) {
                if(isset($file_ext_mime[mb_strtolower($file_type, 'UTF-8')])) {
                    $allowed_mime_type .= $file_ext_mime[mb_strtolower($file_type, 'UTF-8')].",";
                }
            }
        }
    }

    $allowed_mime_type = trim($allowed_mime_type, ",");

    $allowed_size = 0; 

    if ( $file_size_a = $tag->get_option( 'limit' ) ) {
        $limit_pattern = '/^([1-9][0-9]*)([kKmM]?[bB])?$/';

        foreach ( $file_size_a as $file_size ) {
            if ( preg_match( $limit_pattern, $file_size, $matches ) ) {
                $allowed_size = (int) $matches[1];

                if ( ! empty( $matches[2] ) ) {
                    $kbmb = mb_strtolower( $matches[2], 'UTF-8' );

                    if ( 'kb' == $kbmb )
                        $allowed_size *= 1024;
                    elseif ( 'mb' == $kbmb )
                        $allowed_size *= 1024 * 1024;
                }

                break;
            }
        }
    }

    $atts['size'] = $tag->get_size_option( '40' );
    $atts['class'] = $tag->get_class_option( $class );
    $atts['tabindex'] = $tag->get_option( 'tabindex', 'int', true );
    $atts['accept'] = $allowed_mime_type;
    if($allowed_size > 0){
        $atts['data-maxfilesize'] = $allowed_size;
    }

    if ( $tag->is_required() ) {
        $atts['aria-required'] = 'true';
    }

    $atts['aria-invalid'] = $validation_error ? 'true' : 'false';

    $atts['type'] = 'file';
    $atts['name'] = $tag->name;
    $atts['multiple'] = "multiple";
    $atts['name'] = $tag->name."[]";

    // Count
    if($files_count = $tag->get_option( 'count' )) {
        $atts['data-count'] = $files_count[0];
    }

    $atts = wpcf7_format_atts( $atts );

    $html = sprintf(
        '<span class="wpcf7-form-control-wrap %1$s" style="position: static;"><input %2$s />%3$s</span>',
        sanitize_html_class( $tag->name ), $atts, $validation_error );

    return $html;
}

/* Encode type filter */

add_filter( 'wpcf7_form_enctype', 'wpcf7_file_form_enctype_filter_drop_uploader' );

function wpcf7_file_form_enctype_filter_drop_uploader( $enctype ) {
    if(version_compare(WPCF7_VERSION, "4.7" ) >= 0) {
        $multipart = (bool) wpcf7_scan_form_tags( array( 'type' => array( 'dropuploader', 'dropuploader*' ) ) );
    } else {
        $multipart = (bool) wpcf7_scan_shortcode( array( 'type' => array( 'dropuploader', 'dropuploader*' ) ) );
    }
    
    if ( $multipart ) {
        $enctype = 'multipart/form-data';
    }

    return $enctype;
}

/* Tag generator */

add_action( 'wpcf7_admin_init', 'wpcf7_add_tag_generator_file_drop_uploader', 50 );

function wpcf7_add_tag_generator_file_drop_uploader() {
    $tag_generator = WPCF7_TagGenerator::get_instance();
    $tag_generator->add( 'dropuploader', esc_html__( 'Drop Uploader', 'cf7-drop-uploader' ),
        'wpcf7_tag_generator_file_drop_uploader' );
}

function wpcf7_tag_generator_file_drop_uploader( $contact_form, $args = '' ) {
    $args = wp_parse_args( $args, array() );
    $type = 'dropuploader';

?>
<div class="control-box">
<fieldset>

<table class="form-table">
<tbody>
    <tr>
    <th scope="row"><?php echo esc_html__( 'Field type', 'cf7-drop-uploader' ); ?></th>
    <td>
        <fieldset>
        <legend class="screen-reader-text"><?php echo esc_html__( 'Field type', 'cf7-drop-uploader' ); ?></legend>
        <label><input type="checkbox" name="required" /> <?php echo esc_html( __( 'Required field', 'cf7-drop-uploader' ) ); ?></label>
        </fieldset>
    </td>
    </tr>

    <tr>
    <th scope="row"><label for="<?php echo esc_attr( $args['content'] . '-name' ); ?>"><?php echo esc_html__( 'Name', 'cf7-drop-uploader' ); ?></label></th>
    <td><input type="text" name="name" class="tg-name oneline" id="<?php echo esc_attr( $args['content'] . '-name' ); ?>" /></td>
    </tr>

    <tr>
    <th scope="row"><label for="<?php echo esc_attr( $args['content'] . '-limit' ); ?>"><?php echo esc_html__( "File size limit (bytes)", 'cf7-drop-uploader' ); ?></label></th>
    <td><input type="text" name="limit" class="filesize oneline option" id="<?php echo esc_attr( $args['content'] . '-limit' ); ?>" /></td>
    </tr>

    <tr>
    <th scope="row"><label for="<?php echo esc_attr( $args['content'] . '-count' ); ?>"><?php echo esc_html__( "Files count limit", 'cf7-drop-uploader' ); ?></label></th>
    <td><input type="text" name="count" class="filesize oneline option" id="<?php echo esc_attr( $args['content'] . '-count' ); ?>" /></td>
    </tr>

    <tr>
    <th scope="row"><label for="<?php echo esc_attr( $args['content'] . '-filetypes' ); ?>"><?php echo esc_html__( 'Acceptable file types', 'cf7-drop-uploader' ); ?></label></th>
    <td><input type="text" name="filetypes" class="filetype oneline option" id="<?php echo esc_attr( $args['content'] . '-filetypes' ); ?>" /></td>
    </tr>

</tbody>
</table>
</fieldset>
</div>

<div class="insert-box">
    <input type="text" name="<?php echo $type; ?>" class="tag code" readonly="readonly" onfocus="this.select()" />

    <div class="submitbox">
    <input type="button" class="button button-primary insert-tag" value="<?php echo esc_attr__( 'Insert Tag', 'cf7-drop-uploader' ); ?>" />
    </div>

    <br class="clear" />

    <p class="description mail-tag"><label for="<?php echo esc_attr( $args['content'] . '-mailtag' ); ?>"><?php echo sprintf( esc_html__( "To attach the file uploaded through this field to mail, you need to insert the corresponding mail-tag (%s) into the File Attachments field on the Mail tab.", 'cf7-drop-uploader' ) , '<strong><span class="mail-tag"></span></strong>' ); ?><input type="text" class="mail-tag code hidden" readonly="readonly" id="<?php echo esc_attr( $args['content'] . '-mailtag' ); ?>" /></label></p>
</div>

<script>

</script>
<?php
}