<?php 

/* Validation + upload handling filter */

add_filter( 'wpcf7_validate_dropuploader', 'wpcf7_file_validation_filter_drop_uploader', 10, 2 );
add_filter( 'wpcf7_validate_dropuploader*', 'wpcf7_file_validation_filter_drop_uploader', 10, 2 );

function wpcf7_file_validation_filter_drop_uploader( $result, $tag ) {
    global $wpdb;

    $cf7du_files = get_option( 'cf7du_files' );

    $table_name = $wpdb->prefix . "cf7_drop_uploader";

    if(version_compare(WPCF7_VERSION, "4.7" ) >= 0) {
        $tag = new WPCF7_FormTag( $tag );
    } else {
        $tag = new WPCF7_Shortcode( $tag );
    }

    if(!$result->is_valid()) {
        return $result;
    }

    $name = $tag->name;

    $id = $tag->get_id_option();

    $empty = true;

    // Get files path from hidden fields
    if(isset($_REQUEST[$tag->name])) {
        $ajax_files_id_array = $_REQUEST[$tag->name];
    } else {
        $ajax_files_id_array = false;
    }

    $ajax_files = "";

    if(is_array($ajax_files_id_array)) {
        foreach ($ajax_files_id_array as $key=>$fileid) {
            $res = $wpdb->get_row("SELECT * FROM $table_name WHERE fileid = '$fileid'");
            $ajax_files .= $res->filepath.";";
        }
    }

    //$ajax_files = rtrim($ajax_files, ";");

    if ( $submission = WPCF7_Submission::get_instance() ) {
        if($ajax_files != "") {
            // Add files as attachments
            $submission->add_uploaded_file( $tag->name, $ajax_files );
        }

        $contact_form = $submission->get_contact_form();

        $contact_form_id = $contact_form->id();

        $cf7du_folder = get_post_meta( $contact_form_id, '_cf7du_folder', true );

        $cf7du_folder_enable = get_post_meta( $contact_form_id, '_cf7du_folder_enable', true );

    }

    if($ajax_files != "") {
        $empty = false;
    }

    if ( $empty && $tag->is_required() ) {
        $result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
    }

    return $result;
}


/* Drop Uploader File Links */

add_filter('wpcf7_posted_data', 'wpcf7_posted_data_drop_uploader');

function wpcf7_posted_data_drop_uploader($posted_data) {
    global $wpdb;

    $table_name = $wpdb->prefix . "cf7_drop_uploader";

    $rand_submission_id = $posted_data['cf7du_submission_id'];

    $cf7du_options = get_option( 'cf7du_options' );

    $cf7du_files = get_option( 'cf7du_files' );

    $contact_form = WPCF7_ContactForm::get_instance($posted_data['_wpcf7']);

    $tags_array = $contact_form->scan_form_tags();

    $drop_uploader_tag_names = array();

    if(is_array($tags_array)){
        foreach ($tags_array as $tag) {
            if($tag['basetype'] == 'dropuploader') {
                $drop_uploader_tag_names[] = $tag['name'];
            }
        }
    }

    $dropbox_file_path = "";

    $copy_file_path = "";

    $submission_from_date = date("Y-m-d H:i:s");

    foreach ($posted_data as $key => $data) {
        if(in_array($key, $drop_uploader_tag_names)) {
            if(is_array($data)) {

                foreach ($data as $k=>$fileid) {
                    $res = $wpdb->get_row("SELECT * FROM $table_name WHERE fileid = '$fileid'");

                    $pathinfo = pathinfo($res->filepath);

                    if(isset($cf7du_files['cf7du_dropbox_enable']) &&
                    isset($cf7du_files['cf7du_dropbox_token']) && 
                    $cf7du_files['cf7du_dropbox_enable'] == 'checked' &&
                    $cf7du_files['cf7du_dropbox_token'] != '') {

                        // If everything ok - finalize dropbox uploaded files

                        $db_filename = $res->filename;
                        $dbsid = $res->dbsid;
                        $dbfsize = $res->dbfsize;

                        $filepath = "";

                        if(isset($cf7du_folder_enable) && $cf7du_folder_enable == "on") {
                            if(isset($cf7du_folder) && $cf7du_folder != '') {
                                $filepath .= $cf7du_folder . "/";
                            }
                        }

                        $filepath .= "Submission from " . $submission_from_date;

                        $cf7du_dropbox = new CF7DUDropbox($fileid);

                        if(isset($dbsid) && isset($db_filename) && isset($dbfsize)) {

                            $cf7du_dropbox->finish_session($dbsid, $filepath . "/" . stripslashes($db_filename), $dbfsize);

                            // Generate share link

                            if(isset($cf7du_files['cf7du_dropbox_generate_link']) && $cf7du_files['cf7du_dropbox_generate_link'] == 'checked') {
                                $cf7du_share_link = $cf7du_dropbox->get_share_link($filepath . "/" . stripslashes($db_filename));
                            } else {
                                $cf7du_share_link = "";
                            }

                            // Save share link to Database

                            $wpdb->update( $table_name,
                                array( 
                                    'dbslink' => $cf7du_share_link,
                                    'dbsid' => ''
                                ),
                                array( 'fileid' => $fileid )
                            );    

                            if($cf7du_share_link != "") {
                                $dropbox_file_path .= $cf7du_share_link . "\n";
                            }

                            unset($posted_data[$key][$k]);     
                        }

                    } 

                    if(isset($cf7du_files['cf7du_store']) && $cf7du_files['cf7du_store'] == 'checked') {
                        $copy_file_path .= cf7du_copy_temp_file($res->filepath, $rand_submission_id);

                        unset($posted_data[$key][$k]);

                    } else {
                        $fname_array = explode('/', $res->filepath);

                        $fname_count = count($fname_array);

                        $fname = $fname_array[$fname_count - 1];

                        $fname = mb_strtolower(str_replace(" ", "-", $fname), 'UTF-8');

                        $fname = str_replace("'", "", $fname);

                        $copy_file_path .= "\n".$fname;

                        unset($posted_data[$key][$k]);

                    }
                }

                if($dropbox_file_path != "") {
                    $posted_data[$key] = $dropbox_file_path;
                } else {
                    $posted_data[$key] = $copy_file_path;
                }
            }
        }
    }

    return $posted_data;
}

/* Messages */

add_filter( 'wpcf7_messages', 'wpcf7_file_messages_drop_uploader' );

function wpcf7_file_messages_drop_uploader( $messages ) {
    return array_merge( $messages, array(
        'upload_failed' => array(
            'description' => esc_html__( "Uploading a file fails for any reason", 'cf7-drop-uploader' ),
            'default' => esc_html__( "There was an unknown error uploading the file.", 'cf7-drop-uploader' )
        ),

        'upload_file_type_invalid' => array(
            'description' => esc_html__( "Uploaded file is not allowed for file type", 'cf7-drop-uploader' ),
            'default' => esc_html__( "You are not allowed to upload files of this type.", 'cf7-drop-uploader' )
        ),

        'upload_file_too_large' => array(
            'description' => esc_html__( "Uploaded file is too large", 'cf7-drop-uploader' ),
            'default' => esc_html__( "The file is too big.", 'cf7-drop-uploader' )
        ),

        'upload_failed_php_error' => array(
            'description' => esc_html__( "Uploading a file fails for PHP error", 'cf7-drop-uploader' ),
            'default' => esc_html__( "There was an error uploading the file.", 'cf7-drop-uploader' )
        )
    ) );
}

/* Multiple Files */

add_filter( 'wpcf7_mail_components', 'wpcf7_mail_components_drop_uploader' );

function wpcf7_mail_components_drop_uploader($components) {
    
    $new_attachments = array();

    $cf7du_options = get_option( 'cf7du_options' );

    $cf7du_files = get_option( 'cf7du_files' );

    if(is_array($components['attachments'])) {
        foreach ($components['attachments'] as $k => $val) {
            if(isset($components['attachments'][$k])) {
                
                $files_array = explode(";", $components['attachments'][$k]);

                if(isset($cf7du_files['cf7du_archive_attachments']) && $cf7du_files['cf7du_archive_attachments'] == 'checked') {
                    $archive_attachments = true;
                } else {
                    $archive_attachments = false;
                }

                // Send attachments as archive
                if($archive_attachments) {
                    $attachments_name = "Attachments ".date("Y-m-d H-i-s");

                    $zip = new ZipArchive();

                    $wpuploaddir = wp_upload_dir();

                    $randdir = rand(9999999999,999999999999);

                    $archivepath = $wpuploaddir['basedir'].DIRECTORY_SEPARATOR.CF7DU_TMP.DIRECTORY_SEPARATOR.$randdir;

                    mkdir($archivepath);

                    $archivename = $archivepath.DIRECTORY_SEPARATOR.$attachments_name . ".zip";

                    if ($zip->open($archivename, ZipArchive::CREATE)!==TRUE) {
                        // Unable to open archive
                        
                        foreach ($files_array as $key => $value) {
                            if($value != '') {
                                $new_attachments[] = $value;
                            }
                        }
                    }

                    foreach ($files_array as $key => $value) {
                        if($value != '') {
                            
                            $path_array = explode(DIRECTORY_SEPARATOR, $value);

                            $path_array_length = count($path_array);

                            $file_name = $path_array[$path_array_length - 1];

                            $zip->addFile($value, $attachments_name."/".$file_name);
                        }
                    }
                    
                    $zip->close();

                    $new_attachments[] = $archivename;
                } else {
                    foreach ($files_array as $key => $value) {
                        if($value != '') {
                            
                            $new_attachments[] = $value;
                        }
                    }
                }
            }
        }
    }

    if(count($new_attachments) > 0) {
        $components['attachments'] = $new_attachments;
    }
    
    return $components;
}

add_action('wpcf7_mail_sent', 'cf7du_mail_sent_fix_attachments', 10, 1);

function cf7du_mail_sent_fix_attachments($contact_form) {
    if ( $submission = WPCF7_Submission::get_instance() ) {
        $uploaded_files = $submission->uploaded_files();
        if(is_array($uploaded_files)) {
            foreach ($uploaded_files as $key => $file) {
                if(strpos($file, ';') !== false) {
                    $files_array = explode(';', $file);
                    foreach ($files_array as $new_key=>$new_file) {
                        if($new_key == 0) {
                            $submission->add_uploaded_file( $key, $new_file );
                        } else {
                            $submission->add_uploaded_file( $key.$new_key, $new_file );
                        }
                    }
                }
            }
        }
    }
}

function cf7du_copy_temp_file($cf7_file, $rand_submission_id) {

    $cf7du_options = get_option( 'cf7du_options' );

    if($rand_submission_id == '' || $cf7_file == '') {
        return false;
    }

    $cf7_file_name_array = explode(DIRECTORY_SEPARATOR, $cf7_file);

    $cf7_file_name_array_len = count($cf7_file_name_array);

    $cf7_file_name_array_last = $cf7_file_name_array_len - 1;

    $cf7_file_name = $cf7_file_name_array[$cf7_file_name_array_last];

    if(
        stripos($cf7_file_name, '.htaccess') !== FALSE ||
        stripos($cf7_file_name, '.php') !== FALSE ||
        stripos($cf7_file_name, '.phtml') !== FALSE ||
        stripos($cf7_file_name, '.shtml') !== FALSE ||
        stripos($cf7_file_name, '.pl') !== FALSE ||
        stripos($cf7_file_name, '.py') !== FALSE ||
        stripos($cf7_file_name, '.rb') !== FALSE ||
        stripos($cf7_file_name, '.cgi') !== FALSE ||
        stripos($cf7_file_name, '.asp') !== FALSE ||
        stripos($cf7_file_name, '.aspx') !== FALSE
    ) {
        return false;
    }

    $file_name_array = explode("/", $cf7_file);

    $file_name_array_count = count($file_name_array);

    $file_name = $file_name_array[$file_name_array_count - 1];

    $file_name = mb_strtolower(str_replace(" ", "-", $file_name), 'UTF-8');

    $file_name = str_replace("'", "", $file_name);

    $wp_upload_dir = wp_upload_dir();

    $cf7du_upload_dir = $wp_upload_dir['basedir'].DIRECTORY_SEPARATOR.CF7DU_FOLDER.DIRECTORY_SEPARATOR.$rand_submission_id.DIRECTORY_SEPARATOR;

    if (!file_exists($cf7du_upload_dir)) {

        mkdir($cf7du_upload_dir, 0755, true);

        // Add .htaccess file

        $htaccess_content = '<Files ~ "\.(php|php3|php4|php5|phtml|shtml|py|pl|cgi|pcgi4|pcgi5)$">
             Order Deny,Allow
             Deny from All
        </Files>';

        $htaccess_file = fopen($cf7du_upload_dir.".htaccess", "w");

        fwrite($htaccess_file, $htaccess_content);

        fclose($htaccess_file);
    }

    $new_file_path = $cf7du_upload_dir.$file_name;

    if(copy($cf7_file, $new_file_path)) {
        return "\n".$wp_upload_dir['baseurl']."/".CF7DU_FOLDER."/".$rand_submission_id."/".urlencode($file_name);
    }
    
    return false;
}

// Remove old uploaded files

function cf7du_clean_files() {
    $wpuploaddir = wp_upload_dir();
    $uploaddir = $wpuploaddir['basedir'].DIRECTORY_SEPARATOR.CF7DU_TMP;

    foreach (glob($uploaddir.DIRECTORY_SEPARATOR."*") as $dir) {
        $dir_stat = stat($dir);
        if(time() - $dir_stat['ctime'] > 60 * 60){
            cf7_du_rrmdir($dir);
        }
    }
}

function cf7_du_rrmdir($dir) {
    if (is_dir($dir)) {
        $objects = scandir($dir);
        foreach ($objects as $object) {
            if ($object != "." && $object != "..") {
                if (is_dir($dir . "/" . $object)) {
                    cf7_du_rrmdir($dir . "/" . $object);
                } else {
                    unlink($dir . "/" . $object);
                }

            }
        }
        rmdir($dir);
    }
}

// Sanitize

function cf7du_sanitize($string = '') {
    // remove html tags
    $clean = strip_tags($string);
    // transliterate
    if(function_exists('transliterator_transliterate')){
        $clean = transliterator_transliterate('Any-Latin;Latin-ASCII;', $clean);
    }
    // remove non-number and non-letter characters
    $clean = str_replace('--', '-', preg_replace('/[^a-z0-9-.\_]/i', '', preg_replace(array(
        '/\s/',
        '/[^\w-\.\-]/'
    ), array(
        '_',
        ''
    ), $clean)));
    // replace '-' for '_'
    $clean = strtr($clean, array(
        '-' => '_'
    ));
    // remove double '__'
    $positionInString = stripos($clean, '__');
    while ($positionInString !== false) {
        $clean = str_replace('__', '_', $clean);
        $positionInString = stripos($clean, '__');
    }
    // remove '_' from the end and beginning of the string
    $clean = rtrim(ltrim($clean, '_'), '_');
    // lowercase the string
    return mb_strtolower($clean, 'UTF-8');
}
