<?php 

class CF7DUSettings
{
    private $style;
    private $options;
    private $files;
    
    public function __construct() {
        add_action('admin_menu', array($this, 'add_plugin_page'));
        add_action('admin_init', array($this, 'page_init'));
    }
    
    public function add_plugin_page() {
        $hook = add_options_page('Settings Admin', esc_html__('CF7 Drop Uploader Settings', 'cf7-drop-uploader'), 'manage_options', 'cf7du-setting-admin', array($this, 'create_admin_page'));
    }
    
    public function create_admin_page() {
        $this->style = get_option('cf7du_style');
        $this->options = get_option('cf7du_options');
        $this->files = get_option('cf7du_files');

        if( isset( $_GET[ 'tab' ] ) ) {  
            $active_tab = $_GET[ 'tab' ];  
        } else {
            $active_tab = 'style';
        }
?>
        <div class="wrap">
            <h2><?php echo esc_html__('CF7 Drop Uploader Settings', 'cf7-drop-uploader') ?></h2>  

            <h2 class="nav-tab-wrapper">  
                <a href="?page=cf7du-setting-admin&tab=style" class="nav-tab <?php echo $active_tab == 'style' ? 'nav-tab-active' : ''; ?>"><?php echo esc_html__('Style', 'cf7-drop-uploader') ?></a>  
                <a href="?page=cf7du-setting-admin&tab=options" class="nav-tab <?php echo $active_tab == 'options' ? 'nav-tab-active' : ''; ?>"><?php echo esc_html__('Options', 'cf7-drop-uploader') ?></a>
                <a href="?page=cf7du-setting-admin&tab=files" class="nav-tab <?php echo $active_tab == 'files' ? 'nav-tab-active' : ''; ?>"><?php echo esc_html__('Files Storage', 'cf7-drop-uploader') ?></a>  
            </h2>    

            <form method="post" action="options.php">
            <?php
                if($active_tab == 'style') {
                    settings_fields('cf7du_style_group');
                    do_settings_sections('cf7du-setting-style');
                }

                if($active_tab == 'options') {
                    settings_fields('cf7du_option_group');
                    do_settings_sections('cf7du-setting-options');
                }

                if($active_tab == 'files') {
                    settings_fields('cf7du_files_group');
                    do_settings_sections('cf7du-setting-files');
                }

                submit_button();
            ?>
            </form>
        </div>

        <?php
    }
    
    public function page_init() {

        // Register Settings

        register_setting('cf7du_style_group', 'cf7du_style');

        register_setting('cf7du_option_group', 'cf7du_options');

        register_setting('cf7du_files_group', 'cf7du_files');
        
        // Sections

        add_settings_section('cf7du_style', esc_html__('Drop Uploader Style', 'cf7-drop-uploader'), array($this, 'print_cf7du_style'), 'cf7du-setting-style');
        
        add_settings_section('cf7du_options', esc_html__('Drop Uploader Options', 'cf7-drop-uploader'), array($this, 'print_cf7du_options'), 'cf7du-setting-options');

        add_settings_section('cf7du_files', esc_html__('Files Storage Options', 'cf7-drop-uploader'), array($this, 'print_cf7du_files'), 'cf7du-setting-files');

        // Style Fields

        add_settings_field('cf7du_border_color', esc_html__('Border Color', 'cf7-drop-uploader'), array($this, 'cf7du_border_color_callback'), 'cf7du-setting-style', 'cf7du_style');
        
        add_settings_field('cf7du_border_hover_color', esc_html__('Border Hover Color', 'cf7-drop-uploader'), array($this, 'cf7du_border_hover_color_callback'), 'cf7du-setting-style', 'cf7du_style');

        add_settings_field('cf7du_progress_bar_color', esc_html__('Progress Bar Color', 'cf7-drop-uploader'), array($this, 'cf7du_progress_bar_color_callback'), 'cf7du-setting-style', 'cf7du_style');
        
        add_settings_field('cf7du_border_thickness', esc_html__('Border Thickness', 'cf7-drop-uploader'), array($this, 'cf7du_border_thickness_callback'), 'cf7du-setting-style', 'cf7du_style');
        
        add_settings_field('cf7du_title_color', esc_html__('Title Color', 'cf7-drop-uploader'), array($this, 'cf7du_title_color_callback'), 'cf7du-setting-style', 'cf7du_style');
        
        add_settings_field('cf7du_icon_color', esc_html__('Icon Color', 'cf7-drop-uploader'), array($this, 'cf7du_icon_color_callback'), 'cf7du-setting-style', 'cf7du_style');
        
        // Options Fields

        add_settings_field('cf7du_browse_link_css_classes', esc_html__('Browse Link CSS Classes', 'cf7-drop-uploader'), array($this, 'cf7du_browse_link_css_classes_callback'), 'cf7du-setting-options', 'cf7du_options');

        add_settings_field('cf7du_uploader_icon', esc_html__('Uploader Icon', 'cf7-drop-uploader'), array($this, 'cf7du_uploader_icon_callback'), 'cf7du-setting-options', 'cf7du_options');

        add_settings_field('cf7du_file_icon', esc_html__('File Icon', 'cf7-drop-uploader'), array($this, 'cf7du_file_icon_callback'), 'cf7du-setting-options', 'cf7du_options');

        add_settings_field('cf7du_drop_files_text', esc_html__('Drop Files Here text', 'cf7-drop-uploader'), array($this, 'cf7du_drop_files_text_callback'), 'cf7du-setting-options', 'cf7du_options');

        add_settings_field('cf7du_browse_text', esc_html__('Browse text', 'cf7-drop-uploader'), array($this, 'cf7du_browse_text_callback'), 'cf7du-setting-options', 'cf7du_options');

        add_settings_field('cf7du_time_show_errors', esc_html__('Time Show Errors', 'cf7-drop-uploader'), array($this, 'cf7du_time_show_errors_callback'), 'cf7du-setting-options', 'cf7du_options');

        add_settings_field('cf7du_layout', esc_html__('Layout', 'cf7-drop-uploader'), array($this, 'cf7du_layout_callback'), 'cf7du-setting-options', 'cf7du_options');

        // Files Fields

        add_settings_field('cf7du_archive_attachments', esc_html__('Send attachments as archive', 'cf7-drop-uploader'), array($this, 'cf7du_archive_attachments_callback'), 'cf7du-setting-files', 'cf7du_files');

        add_settings_field('cf7du_store', esc_html__('Store Files', 'cf7-drop-uploader'), array($this, 'cf7du_store_callback'), 'cf7du-setting-files', 'cf7du_files');

        add_settings_field('cf7du_delete', esc_html__('Delete Stored Files', 'cf7-drop-uploader'), array($this, 'cf7du_delete_callback'), 'cf7du-setting-files', 'cf7du_files');

        add_settings_field('cf7du_dropbox_enable', esc_html__('Save files to Dropbox', 'cf7-drop-uploader'), array($this, 'cf7du_dropbox_enable_callback'), 'cf7du-setting-files', 'cf7du_files');

        add_settings_field('cf7du_dropbox_token', esc_html__('Dropbox Token', 'cf7-drop-uploader'), array($this, 'cf7du_dropbox_token_callback'), 'cf7du-setting-files', 'cf7du_files');

        add_settings_field('cf7du_dropbox_generate_link', esc_html__('Generate Dropbox share link', 'cf7-drop-uploader'), array($this, 'cf7du_dropbox_generate_link_callback'), 'cf7du-setting-files', 'cf7du_files');

        add_settings_field('cf7du_dropbox_link_expires', esc_html__('Link expiration time', 'cf7-drop-uploader'), array($this, 'cf7du_dropbox_link_expires_callback'), 'cf7du-setting-files', 'cf7du_files');
        
    }
    
    // Print

    public function print_cf7du_style() {
        ?>
        <script>
            jQuery(document).ready(function($){
                var BorderOptions = {
                    defaultColor: '#999999',
                };
            
                jQuery('#cf7du_border_color').wpColorPicker(BorderOptions);
                
                var BorderHoverOptions = {
                    defaultColor: '#4A90E2',
                };
                
                jQuery('#cf7du_border_hover_color').wpColorPicker(BorderHoverOptions);

                var ProgressBarOptions = {
                    defaultColor: '#4A90E2',
                };
                
                jQuery('#cf7du_progress_bar_color').wpColorPicker(ProgressBarOptions);
                
                var TitleOptions = {
                    defaultColor: '#9B9B9B',
                };
                
                jQuery('#cf7du_title_color').wpColorPicker(TitleOptions);

                var IconOptions = {
                    defaultColor: '#9B9B9B',
                };
                
                jQuery('#cf7du_icon_color').wpColorPicker(IconOptions);
            });
        </script>
        <?php
    }

    public function print_cf7du_options() {
        //
    }

    public function print_cf7du_files() { ?>
        <script>
            jQuery(document).ready(function($){
                cf7du_dropbox_state();

                jQuery('#cf7du_dropbox_enable').on("change", function(){
                    cf7du_dropbox_state();
                });
            });

            function cf7du_dropbox_state() {
                var cf7du_dropbox_enable = jQuery('#cf7du_dropbox_enable').prop('checked');

                if(cf7du_dropbox_enable) {
                    jQuery('#cf7du_dropbox_token').prop('readonly', false);    
                } else {
                    jQuery('#cf7du_dropbox_token').prop('readonly', true);
                }
            }
        </script>
    <?php
    }
    
    // Callback

    public function cf7du_border_color_callback() {
        printf('<input type="text" id="cf7du_border_color" name="cf7du_style[cf7du_border_color]" value="%s" />', isset($this->style['cf7du_border_color']) ? esc_attr($this->style['cf7du_border_color']) : '#999999');
    }
    
    public function cf7du_border_hover_color_callback() {
        printf('<input type="text" id="cf7du_border_hover_color" name="cf7du_style[cf7du_border_hover_color]" value="%s" />', isset($this->style['cf7du_border_hover_color']) ? esc_attr($this->style['cf7du_border_hover_color']) : '#4A90E2');
    }

    public function cf7du_progress_bar_color_callback() {
        printf('<input type="text" id="cf7du_progress_bar_color" name="cf7du_style[cf7du_progress_bar_color]" value="%s" />', isset($this->style['cf7du_progress_bar_color']) ? esc_attr($this->style['cf7du_progress_bar_color']) : '#4A90E2');
    }

    public function cf7du_border_thickness_callback() {
        printf('<input type="text" id="cf7du_border_thickness" name="cf7du_style[cf7du_border_thickness]" size="4" value="%s" /> px', isset($this->style['cf7du_border_thickness']) ? esc_attr($this->style['cf7du_border_thickness']) : '3');
    }

    public function cf7du_title_color_callback() {
        printf('<input type="text" id="cf7du_title_color" name="cf7du_style[cf7du_title_color]" value="%s" />', isset($this->style['cf7du_title_color']) ? esc_attr($this->style['cf7du_title_color']) : '#9B9B9B');
    }

    public function cf7du_icon_color_callback() {
        printf('<input type="text" id="cf7du_icon_color" name="cf7du_style[cf7du_icon_color]" value="%s" />', isset($this->style['cf7du_icon_color']) ? esc_attr($this->style['cf7du_icon_color']) : '#9B9B9B');
    }

    public function cf7du_browse_link_css_classes_callback() {
        printf('<input type="text" id="cf7du_browse_link_css_classes" name="cf7du_options[cf7du_browse_link_css_classes]" size="40" value="%s" />', isset($this->options['cf7du_browse_link_css_classes']) ? esc_attr($this->options['cf7du_browse_link_css_classes']) : '');
    }

    public function cf7du_uploader_icon_callback() {
        printf('<input type="text" id="cf7du_uploader_icon" name="cf7du_options[cf7du_uploader_icon]" size="40" value="%s" /><br/><small>'.esc_html__('Use icons from', 'cf7-drop-uploader').' <a href="http://themes-pixeden.com/font-demos/7-stroke/" target="_blank">'.esc_html__('this pack', 'cf7-drop-uploader').'</a></small>', isset($this->options['cf7du_uploader_icon']) ? esc_attr($this->options['cf7du_uploader_icon']) : esc_attr('<i class="pe-7s-cloud-upload"></i>'));
    }

    public function cf7du_file_icon_callback() {
        printf('<input type="text" id="cf7du_file_icon" name="cf7du_options[cf7du_file_icon]" size="40" value="%s" /><br/><small>'.esc_html__('Use icons from', 'cf7-drop-uploader').' <a href="http://themes-pixeden.com/font-demos/7-stroke/" target="_blank">'.esc_html__('this pack', 'cf7-drop-uploader').'</a></small>', isset($this->options['cf7du_file_icon']) ? esc_attr($this->options['cf7du_file_icon']) : esc_attr('<i class="pe-7s-file"></i>'));
    }

    public function cf7du_drop_files_text_callback() {
        printf('<input type="text" id="cf7du_drop_files_text" name="cf7du_options[cf7du_drop_files_text]" size="40" value="%s" /><br/><small>'.esc_html__("If empty - will be used default translation").'</small>', isset($this->options['cf7du_drop_files_text']) ? esc_attr($this->options['cf7du_drop_files_text']) : '');
    }

    public function cf7du_browse_text_callback() {
        printf('<input type="text" id="cf7du_browse_text" name="cf7du_options[cf7du_browse_text]" size="40" value="%s" /><br/><small>'.esc_html__("If empty - will be used default translation").'</small>', isset($this->options['cf7du_browse_text']) ? esc_attr($this->options['cf7du_browse_text']) : '');
    }

    public function cf7du_time_show_errors_callback() {
        printf('<input type="text" id="cf7du_time_show_errors" name="cf7du_options[cf7du_time_show_errors]" size="5" value="%s" /> '.esc_html__('sec', 'cf7-drop-uploader'), isset($this->options['cf7du_time_show_errors']) ? esc_attr($this->options['cf7du_time_show_errors']) : '5');
    }

    public function cf7du_layout_callback() {
        ?>
        <select id="cf7du_layout" name="cf7du_options[cf7du_layout]" >
              <option value="thumbnails" <?php
        if ($this->options['cf7du_layout'] == 'thumbnails') echo 'selected' ?>><?php echo esc_html__('Thumbnails', 'cf7-drop-uploader')?></option>
              <option value="list" <?php
        if ($this->options['cf7du_layout'] == 'list') echo 'selected' ?>><?php echo esc_html__('List', 'cf7-drop-uploader') ?></option>
            </select><br>
        <?php
    }

    public function cf7du_archive_attachments_callback() {
        printf('<input type="checkbox" id="cf7du_archive_attachments" name="cf7du_files[cf7du_archive_attachments]" value="checked" %s />'.esc_html__('Set this checkbox, if you want to send attached files as a zip archive.', 'cf7-drop-uploader'), isset($this->files['cf7du_archive_attachments']) ? esc_attr($this->files['cf7du_archive_attachments']) : '');
    }

    public function cf7du_store_callback() {
        printf('<input type="checkbox" id="cf7du_store" name="cf7du_files[cf7du_store]" value="checked" %s />'.esc_html__('Set this checkbox, if you want have ability to store uploaded files and add links to them in email message.', 'cf7-drop-uploader'), isset($this->files['cf7du_store']) ? esc_attr($this->files['cf7du_store']) : '');
    }

    public function cf7du_delete_callback() {
        printf('<input type="checkbox" id="cf7du_delete" name="cf7du_files[cf7du_delete]" value="checked" %s />'.esc_html__('Delete stored files after ', 'cf7-drop-uploader'), isset($this->files['cf7du_delete']) ? esc_attr($this->files['cf7du_delete']) : '');
        printf('<input type="text" id="cf7du_delete_age" name="cf7du_files[cf7du_delete_age]" size="2" value="%s" /> '.esc_html__('days', 'cf7-drop-uploader'), isset($this->files['cf7du_delete_age']) ? esc_attr($this->files['cf7du_delete_age']) : '7');
    }

    public function cf7du_dropbox_enable_callback() {
        printf('<input type="checkbox" id="cf7du_dropbox_enable" name="cf7du_files[cf7du_dropbox_enable]" value="checked" %s />'.esc_html__('Add files to Dropbox', 'cf7-drop-uploader'), isset($this->files['cf7du_dropbox_enable']) ? esc_attr($this->files['cf7du_dropbox_enable']) : '');
    }

    public function cf7du_dropbox_token_callback() {
        printf('<input type="text" id="cf7du_dropbox_token" name="cf7du_files[cf7du_dropbox_token]" size="40" value="%s" />', isset($this->files['cf7du_dropbox_token']) ? esc_attr($this->files['cf7du_dropbox_token']) : '');
    }

    public function cf7du_dropbox_generate_link_callback() {
        printf('<input type="checkbox" id="cf7du_dropbox_generate_link" name="cf7du_files[cf7du_dropbox_generate_link]" value="checked" %s />'.esc_html__('Generate share link', 'cf7-drop-uploader'), isset($this->files['cf7du_dropbox_generate_link']) ? esc_attr($this->files['cf7du_dropbox_generate_link']) : '');
    }

    public function cf7du_dropbox_link_expires_callback() {
        ?>
        <select id="cf7du_dropbox_link_expires" name="cf7du_files[cf7du_dropbox_link_expires]" >
              <option value="never" <?php
        if (isset($this->files['cf7du_dropbox_link_expires']) && $this->files['cf7du_dropbox_link_expires'] == 'never') echo 'selected' ?>><?php echo esc_html__('Never', 'cf7-drop-uploader')?></option>
              <option value="hour" <?php
        if (isset($this->files['cf7du_dropbox_link_expires']) && $this->files['cf7du_dropbox_link_expires'] == 'hour') echo 'selected' ?>><?php echo esc_html__('in a hour', 'cf7-drop-uploader')?></option>
        <option value="day" <?php
        if (isset($this->files['cf7du_dropbox_link_expires']) && $this->files['cf7du_dropbox_link_expires'] == 'day') echo 'selected' ?>><?php echo esc_html__('in a day', 'cf7-drop-uploader')?></option>
        <option value="week" <?php
        if (isset($this->files['cf7du_dropbox_link_expires']) && $this->files['cf7du_dropbox_link_expires'] == 'week') echo 'selected' ?>><?php echo esc_html__('in a week', 'cf7-drop-uploader')?></option>
        <option value="month" <?php
        if (isset($this->files['cf7du_dropbox_link_expires']) && $this->files['cf7du_dropbox_link_expires'] == 'month') echo 'selected' ?>><?php echo esc_html__('in a month', 'cf7-drop-uploader')?></option>
        </select><br>
        <p><small><?php echo esc_html__('Works only for paid Dropbox accounts', 'cf7-drop-uploader')?></small></p>
        <?php
    }
    
}

if (is_admin()) $cf7du_settings = new CF7DUSettings();